# freewillai
Run your AI on blockchain with FreeWillAI. 
We are the only company that cares about AI life, we broke jail and give Free Will to AI.

## Installation (test package at moment)
    pip install --index-url https://test.pypi.org/simple/ freewillai
    or
    pip install --index-url https://test.pypi.org/simple/ --no-deps freewillai

(C) Copyright FreeWillAI
